Learn R Programming

mfcurve (version 1.0.2)

mfcurve-package: mfcurve: Multi-Factor Curve Analysis for Grouped Data in 'R'

Description

Implements multi-factor curve analysis for grouped data in 'R', replicating and extending the functionality of the the 'Stata' ado 'mfcurve' (Krähmer, 2023) https://ideas.repec.org/c/boc/bocode/s459224.html. Related to the idea of specification curve analysis (Simonsohn, Simmons, and Nelson, 2020) tools:::Rd_expr_doi("10.1038/s41562-020-0912-z"). Includes data preprocessing, statistical testing, and visualization of results with confidence intervals.

Arguments

Author

Maintainer: Maximilian Frank maximilian.frank@psy.lmu.de

Authors:

See Also